@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 import sys
 import unittest
+
 try:
     from unittest.mock import patch
 except ImportError:
@@ -11,11 +12,10 @@ from django_migration_checker.cli.find_conflicts import create_parser
 
 
 class TestFindMigrationsCliChecker(unittest.TestCase):
-
     def setUp(self):
         self.parser = create_parser()
-        self.apps_dir = 'apps_dir'
-        self.valid_parsed_args = self.parser.parse_args([self.apps_dir])
+        self.apps_dir_input = "example_app_dir"
+        self.valid_parsed_args = self.parser.parse_args([self.apps_dir_input])
 
     def test_with_empty_args(self):
         """
@@ -29,17 +29,17 @@ class TestFindMigrationsCliChecker(unittest.TestCase):
         """
         args = self.valid_parsed_args
 
-        assert args.apps_dir == self.apps_dir
+        assert args.apps_dirs == [self.apps_dir_input]
 
-    @patch('django_migration_checker.cli.find_conflicts.get_conflicts')
-    @patch('argparse.ArgumentParser.parse_args')
+    @patch("django_migration_checker.cli.find_conflicts.get_conflicts")
+    @patch("argparse.ArgumentParser.parse_args")
     def test_cli_passes_args(self, m_parse_args, m_get_conflicts):
         m_parse_args.return_value = self.valid_parsed_args
 
         self.assertRaises(SystemExit, find_conflicts.main)
 
-        m_get_conflicts.assert_called_with(self.apps_dir)
+        m_get_conflicts.assert_called_with(self.apps_dir_input)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(unittest.main())
